c_listlengths: A simple function to compute the lengths of the elements of...

View source: R/RcppExports.R

c_listlengthsR Documentation

A simple function to compute the lengths of the elements of an R list

Description

A simple function to compute the lengths of the elements of an R list

Usage

c_listlengths(L)

Arguments

L

a list

Details

This is equivalent to the base::lengths however it it much faster for long lists (and somewhat slower for short ones).

Value

An integer vector containing the length of each element of L


natcpp documentation built on Sept. 26, 2026, 9:06 a.m.