| c_topntail | R Documentation |
c_topntail returns an 2xN matrix containing the start and end
of each of the vectors in the input list. Length 0 vectors are ignored, while
length 1 vectors are duplicated
For c_topntail_list, a list of the same length as
L having the same elements when their length is <=2 or
the first and last elements when length>2.
c_topntail(L)
c_topntail_list(L)
L |
a list containing integer vectors, typically a |
For c_topntail an integer matrix. For c_topntail_list
a list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.