natcpp-package: natcpp: Fast C++ Primitives for the 'NeuroAnatomy Toolbox'

natcpp-packageR Documentation

natcpp: Fast C++ Primitives for the 'NeuroAnatomy Toolbox'

Description

Fast functions implemented in C++ via 'Rcpp' to support the 'NeuroAnatomy Toolbox' ('nat') ecosystem. These functions provide large speed-ups for basic manipulation of neuronal skeletons over pure R functions found in the 'nat' package. The expectation is that end users will not use this package directly, but instead the 'nat' package will automatically use routines from this package when it is available to enable large performance gains.

Author(s)

Maintainer: Gregory Jefferis jefferis@gmail.com (ORCID)

Authors:

Other contributors:

  • libigl contributors (bundled libigl fast winding number code (MPL-2.0); see src/vendor/README.md) [contributor, copyright holder]

See Also

Useful links:


natcpp documentation built on Sept. 26, 2026, 9:06 a.m.