| c_listlengths | R Documentation |
A simple function to compute the lengths of the elements of an R list
c_listlengths(L)
L |
a list |
This is equivalent to the base::lengths however it it much
faster for long lists (and somewhat slower for short ones).
An integer vector containing the length of each element of L
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.