| natcpp-package | R Documentation |
Fast functions implemented in C++ via 'Rcpp' to support the 'NeuroAnatomy Toolbox' ('nat') ecosystem. These functions provide large speed-ups for basic manipulation of neuronal skeletons over pure R functions found in the 'nat' package. The expectation is that end users will not use this package directly, but instead the 'nat' package will automatically use routines from this package when it is available to enable large performance gains.
Maintainer: Gregory Jefferis jefferis@gmail.com (ORCID)
Authors:
Gregory Jefferis jefferis@gmail.com (ORCID)
Other contributors:
libigl contributors (bundled libigl fast winding number code (MPL-2.0); see src/vendor/README.md) [contributor, copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.